# Conformal Classifier

A module for producing conformal predictions using classification

::: photonai_conformal.mapie_wrapper.ConformalClassifier.__init__
    rendering:
        show_root_toc_entry: False